
%%%%%%%%%%%%%%%% The 'big matrix' M of size n x n %%%%%%%%%%%%%%%%%%%%%%%%%
function [S, R, G, D, y] = BigMatrixNotShrinkSens(n,lowval,hival,Lp,Rm,Lm,E_Y,Ystdev,rb,kappa,Lb,mu,perturbation)
% pars perturbed are:   Lb, Lp, Lm, Rm, rb, kappa, mu

% upper and lower integration limits
	L = lowval; U = 1.1*hival;
	% boundary points b and mesh points y
	c = 0:1:n; b = L+c.*(U-L)./n;
    y = 0.5.*(b(1:n)+b(2:n+1));
	% create S, R, G and D matrices
	S = SurvivalFunction(y,E_Y,Lm,mu,kappa,perturbation); S=repmat(S,n,1); S=S.*eye(n);
	R = ReproductionFunction(y,Lp,Rm,Lm,kappa,E_Y,perturbation); R=repmat(R,n,1); R=R.*eye(n);
    G = GrowthFunction(y,E_Y,Ystdev,Lm,rb,perturbation); % plot(y,mutemp)
	D = DevelopmentFunction(y,Lb,perturbation);
	% scale D and G so columns sum to 1
	[m,n]=size(G); G = G./repmat(sum(G),m,1); 
    [m,n]=size(D); D = D./repmat(sum(D),m,1); 

% Compute the kernel component functions from the fitted models

% survival
function [sx] = SurvivalFunction(x,E_Y,Lm,mu,kappa,perturbation)
    for i=1:length(x)
        if x(i) <= Lm*perturbation(3)*E_Y/(perturbation(6)*kappa); % only survivors 
            sx(i) = exp(-mu*perturbation(7));
        else sx(i)=0; end
    end
    
% pars perturbed are: Lb, Lp, Lm, Rm, rb, kappa, mu

% growth
function gxy = GrowthFunction(x,E_Y,Ystdev,Lm,rb,perturbation) 
    for i=1:length(x)
        if (x(i)>0 && x(i)<=Lm*E_Y); % when respiration energy is sufficient to cover maintenance
        mux = x(i).*exp(-rb*perturbation(5)) + (1 - exp(-rb*perturbation(5)))*Lm*perturbation(3)*E_Y;
        sigmax2 = (1 - exp(-rb*perturbation(5)))*Lm*perturbation(3)*Ystdev;
        sigmax = max(0.00001,sigmax2);
        fac1 = sqrt(2.*pi).*sigmax; fac2 = ((x'-mux).^2)./(2.*sigmax.^2);
        gxy(:,i) = (exp(-fac2)./fac1); 
        else gxy(:,i)=x; 
        end; 
     end

% reproduction
function [rx] = ReproductionFunction(x,Lp,Rm,Lm,kappa,E_Y,perturbation)
    rx2 = x>=Lp; % matrix with zeros and ones for inds that are above the threshold size for reproduction
    rx1 = zeros(1,length(x));
    for i=1:length(x)
        if x(i) <= Lm*perturbation(3)*E_Y; % when respiration energy is sufficient to cover maintenance
        rx1(i) =  Rm*perturbation(4)/((Lm*perturbation(3))^2).*E_Y.*x(i).^2; 
        elseif x(i) <= Lm*perturbation(3)*E_Y/(kappa*perturbation(6)); % only survivors reproduce
            rx(i)=Rm*perturbation(4)/(1-kappa*perturbation(6))*(E_Y*x(i).^2-kappa*perturbation(6)*x(i).^3/(Lm*perturbation(3))); end
        rx=rx1.*rx2; % only adults reproduce
    end

% development
function [dxy] = DevelopmentFunction(x,Lb,perturbation)
    xtemp = x<=Lb*perturbation(1); 
    dxy=repmat(xtemp',1,length(xtemp));
    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%