
%%%%%%%%%%%%%%%% The 'big matrix' M of size n x n %%%%%%%%%%%%%%%%%%%%%%%%%
function [Sperturb, Rperturb, Gperturb, Dperturb, y] = BigMatrixShrinkSens(n,lowval,hival,Lp,Rm,Lm,E_Y,E_Ystdev,rb,kappa,MeanEggSize,mu,perturb)
	% upper and lower integration limits
	L = lowval; U = 1.1*hival;
	% boundary points b and mesh points y
	c = 0:1:n; b = L+c.*(U-L)./n;
    y = 0.5.*(b(1:n)+b(2:n+1));
	% create S, R, G and D matrices
	Sperturb = SurvivalFunction(y,E_Y,Lm,mu,kappa,perturb); Sperturb=repmat(Sperturb,n,1); Sperturb=Sperturb.*eye(n); save Sperturb Sperturb
	Rperturb = ReproductionFunction(y,Lp,Rm,Lm,E_Y,perturb); Rperturb=repmat(Rperturb,n,1); Rperturb=Rperturb.*eye(n);save Rperturb Rperturb
    Gperturb = GrowthFunction(y,E_Y,E_Ystdev,Lm,rb,perturb); save Gperturb Gperturb
	Dperturb = DevelopmentFunction(y,MeanEggSize,perturb);save Dperturb Dperturb
	% scale D and G so columns sum to 1
	[m,n]=size(Gperturb); Gperturb = Gperturb./repmat(sum(Gperturb),m,1); 
    [m,n]=size(Dperturb); Dperturb = Dperturb./repmat(sum(Dperturb),m,1); 

% Compute the kernel component functions from the fitted models

% survival
function [sx] = SurvivalFunction(x,E_Y,Lm,mu,kappa,perturb)
    for i=1:length(x)
        if x(i) <= Lm*perturb(3)*E_Y/(kappa*perturb(6));
            sx(i) = exp(-mu*perturb(7));
        else sx(i)=0; end
    end
    
% growth
function gxy = GrowthFunction(x,E_Y,E_Ystdev,Lm,rb,perturb) 
    for i=1:length(x)
        mux = x(i).*exp(-rb*perturb(5)) + (1 - exp(-rb*perturb(5)))*Lm*perturb(3)*E_Y;
        sigmax2 = (1 - exp(-rb*perturb(5)))*Lm*perturb(3)*E_Ystdev;
        sigmax = max(0.00001,sigmax2);
        fac1 = sqrt(2.*pi).*sigmax; fac2 = ((x'-mux).^2)./(2.*sigmax.^2);
        gxy(:,i) = (exp(-fac2)./fac1); 
     end

% reproduction
function [rx] = ReproductionFunction(x,Lp,Rm,Lm,E_Y,perturb)
    rx2 = x>=Lp*perturb(2); % matrix with zeros and ones for inds that are above the threshold size for reproduction
    rx1 = zeros(1,length(x));
    for i=1:length(x)
        rx1(i) =  Rm*perturb(4)/((Lm*perturb(3))^2).*E_Y.*x(i).^2; 
        rx=rx1.*rx2; % only adults reproduce
    end

% development
function [dxy] = DevelopmentFunction(x,MeanEggSize,perturb)
    xtemp = x<=MeanEggSize*perturb(1); 
    dxy=repmat(xtemp',1,length(xtemp));
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%